@@ -449,7 +449,7 @@ class Dataset():
         """
         ori_dist = self.get_data().sum(axis=1)
 
-        if self.__dims:
+        if self.__dims and self.__dims.ndim > 1:
             new_shape = []
             dims_list = []
             for axis, dim in self.__dims:
@@ -735,8 +735,8 @@ class Dataset():
                 return
             new_data = Data(urls, self.running_data.metadata, self._in_memory)
 
-        transformation = ([apply_2D_ROI(axis, origin, size, center) for axis in self.transformation]
-                          if self.transformation else None)
+        transformation = (Transformation(self.transformation.kind, [apply_2D_ROI(axis, origin, size, center) for axis in self.transformation.transformation],
+                          self.transformation.rotate) if self.transformation else None)
         if indices is None:
             shape = list(self.data.shape)[:-2]
             shape.append(new_data.shape[-2])
@@ -914,11 +914,11 @@ class Dataset():
         shift = self.find_shift(dimension, steps, indices=indices)
         return self.apply_shift(shift, dimension, indices=indices)
 
-    def _cascade_nmf(self, num_components, iterations, vstep=None, hstep=None, indices=None):
+    def _waterfall_nmf(self, num_components, iterations, vstep=None, hstep=None, indices=None):
         """
         This method is used as a way to improve the speed of convergence of
-        the NMF method. For this, it uses a cascade methology at every
-        step of the cascade, the data used has a smaller size.
+        the NMF method. For this, it uses a waterfall model where at every step
+        the output matrices serve as input for the next.
         That is, the method starts with a smaller resized images of the data,
         and computes the NMF decomposition. The next step is the same but with
         bigger images, and using as initial H and W the precomputed matrices.
@@ -927,8 +927,8 @@ class Dataset():
         the method converges faster.
 
         :param int num_components: Number of components to find.
-        :param array_like iterations: Array with number of iterations per step of the cascade.
-            The size of the array sets the size of the cascade.
+        :param array_like iterations: Array with number of iterations per step of the waterfall.
+            The size of the array sets the size of the waterfall.
         :param Union[None, array_like] indices: If not None, apply method only to indices of data.
         """
 
@@ -941,21 +941,21 @@ class Dataset():
         first_size = (shape / (len(iterations) + 1)).astype(numpy.int)
         size = first_size
 
-        if not os.path.isdir(self.dir + "/cascade/"):
-            os.mkdir(self.dir + "/cascade/")
+        if not os.path.isdir(self.dir + "/waterfall/"):
+            os.mkdir(self.dir + "/waterfall/")
 
-        _logger.info("Starting cascade NMF")
+        _logger.info("Starting waterfall NMF")
 
         for i in range(len(iterations)):
             new_urls = []
             if indices is None:
                 indices = range(self.nframes)
             for j in indices:
-                filename = self.dir + "/cascade/" + str(j) + ".npy"
+                filename = self.dir + "/waterfall/" + str(j) + ".npy"
                 numpy.save(filename, resize(self.get_data(j), size))
                 new_urls.append(DataUrl(file_path=filename, scheme='fabio'))
             data = Data(new_urls, self.get_data(indices).metadata, self._in_memory)
-            dataset = Dataset(_dir=self.dir + "/cascade/", data=data, in_memory=self._in_memory)
+            dataset = Dataset(_dir=self.dir + "/waterfall/", data=data, in_memory=self._in_memory)
             if vstep:
                 v_step = vstep * (len(iterations) - i)
             if hstep:
@@ -968,9 +968,9 @@ class Dataset():
             H = H2
 
         try:
-            shutil.rmtree(self.dir + "/cascade/")
+            shutil.rmtree(self.dir + "/waterfall/")
         except Exception as e:
-            print('Failed to delete %s. Reason: %s' % (self.dir + "/cascade/", e))
+            print('Failed to delete %s. Reason: %s' % (self.dir + "/waterfall/", e))
 
         H = resize(H, (num_components, shape[0] * shape[1]))
 
@@ -1058,12 +1058,12 @@ class Dataset():
         model = NICA(self.data.convert_to_hdf5(bss_dir), num_components, chunksize, indices=indices)
         try:
             model.fit_transform(max_iter=num_iter, error_step=error_step)
-            return model.H, model.W
+            return numpy.abs(model.H), numpy.abs(model.W)
         finally:
             self.data._file.close()
 
-    def nmf(self, num_components, num_iter=100, error_step=None, cascade=None,
-            H=None, W=None, vstep=100, hstep=1000, indices=None):
+    def nmf(self, num_components, num_iter=100, error_step=None, waterfall=None,
+            H=None, W=None, vstep=100, hstep=1000, indices=None, init=None):
         """
         Compute Non-negative Matrix Factorization on the data.
         The method, first converts, if not already, the data into an hdf5 file object
@@ -1077,13 +1077,13 @@ class Dataset():
             to check for convergence, defaults to None
             TODO: not able for huge datasets.
         :type error_step: Union[None, int], optional
-        :param cascade: If not None, NMF is computed using the cascade method.
+        :param waterfall: If not None, NMF is computed using the waterfall method.
             The parameter should be an array with the number of iterations per
             sub-computation, defaults to None
-        :type cascade: Union[None, array_like], optional
-        :param H: Init matrix for H, defaults to None
+        :type waterfall: Union[None, array_like], optional
+        :param H: Init matrix for H of shape (n_components, n_samples), defaults to None
         :type H: Union[None, array_like], optional
-        :param W: Init matrix for W, defaults to None
+        :param W: Init matrix for W of shape (n_features, n_components), defaults to None
         :type W: Union[None, array_like], optional
         :param indices: If not None, apply method only to indices of data, defaults to None
         :type indices: Union[None, array_like], optional
@@ -1096,7 +1096,7 @@ class Dataset():
 
         if self._in_memory:
             from sklearn import decomposition
-            model = decomposition.NMF(n_components=num_components, init='random', max_iter=num_iter)
+            model = decomposition.NMF(n_components=num_components, init=init)
             if indices is not None:
                 X = self.data.convert_to_hdf5(bss_dir)[indices]
             else:
@@ -1105,13 +1105,17 @@ class Dataset():
                 _logger.warning("Setting negative values to 0 to compute NMF")
                 X[X[:, :] < 0] = 0
             try:
+                if H is not None:
+                    H = H.astype(X.dtype)
+                if W is not None:
+                    W = W.astype(X.dtype)
                 W = model.fit_transform(X, W=W, H=H)
                 return model.components_, W
             finally:
                 self.data._file.close()
         else:
-            if cascade is not None:
-                H, W = self._cascade_nmf(num_components, cascade, vstep, hstep, indices=indices)
+            if waterfall is not None:
+                H, W = self._waterfall_nmf(num_components, waterfall, vstep, hstep, indices=indices)
 
             model = NMF(self.data.convert_to_hdf5(bss_dir), num_components, indices=indices)
             try:
@@ -1120,7 +1124,7 @@ class Dataset():
             finally:
                 self.data._file.close()
 
-    def nica_nmf(self, num_components, chunksize=None, num_iter=500, cascade=None,
+    def nica_nmf(self, num_components, chunksize=None, num_iter=500, waterfall=None,
                  error_step=None, vstep=100, hstep=1000, indices=None):
         """
         Applies both NICA and NMF to the data. The init H and W for NMF are the
@@ -1128,8 +1132,12 @@ class Dataset():
         """
         H, W = self.nica(num_components, chunksize, num_iter, error_step, indices=indices)
 
-        return self.nmf(num_components, num_iter, error_step, cascade, H, W,
-                        vstep, hstep, indices=indices)
+        # Initial NMF factorization: X = F0 * G0
+        W = numpy.abs(W)
+        H = numpy.abs(H)
+
+        return self.nmf(min(num_components, H.shape[0]), num_iter, error_step, waterfall, H, W,
+                        vstep, hstep, indices=indices, init='custom')
 
     def apply_moments(self, indices=None, chunk_shape=[500, 500]):
         """
@@ -1327,20 +1335,42 @@ class Dataset():
         data = Data(new_urls.reshape(self.data.urls.shape), self.data.metadata, in_memory=True)  # to modify
         return Dataset(_dir=_dir, data=data, dims=self.__dims, transformation=self.transformation, in_memory=True)
 
-    def compute_transformation(self, d, kind="magnification", rotate=False):
+    def compute_transformation(self, d, kind="magnification", rotate=False, topography=[False, 0]):
+
+        """
+        Computes transformation matrix.
+        Depending on the kind of transformation, computes either RSM or magnification
+        axes to be used on future widgets.
+
+        :param d: Size of the pixel
+        :type d: float
+        :param kind: Transformation to apply, either 'magnification' or 'rsm'
+        :type kind: str
+        :param rotate: To be used only with kind='rsm', if True the images with
+        transformation are rotated 90 degrees.
+        :type rotate: bool
+        :param topography: To be used only with kind='magnification', if True
+        obpitch values are divided by its sine.
+        :type topography: bool
+        """
 
         H, W = self.get_data(0).shape
+        self.rotate = rotate
 
         if self.dims.ndim == 1 and kind == "rsm":
             ffz = self.get_metadata_values(POSITIONER_METADATA, "ffz")[0]
             mainx = -self.get_metadata_values(POSITIONER_METADATA, "mainx")[0]
-            self.transformation = compute_rsm(H, W, d, ffz, mainx)
+            if rotate:
+                transformation = compute_rsm(W, H, d, ffz, mainx)
+            else:
+                transformation = compute_rsm(H, W, d, ffz, mainx)
+            self.transformation = Transformation(kind, transformation, rotate)
         else:
             obx = self.get_metadata_values(POSITIONER_METADATA, "obx")[0]
             obpitch = self.get_metadata_values(POSITIONER_METADATA, "obpitch")
             obpitch = obpitch[len(obpitch) // 2]
             mainx = -self.get_metadata_values(POSITIONER_METADATA, "mainx")[0]
-            self.transformation = compute_magnification(H, W, d, obx, obpitch, mainx)
+            self.transformation = Transformation(kind, compute_magnification(H, W, d, obx, obpitch, mainx, topography), rotate)
 
     def __deepcopy__(self, memo):
         """
@@ -1710,3 +1740,15 @@ class Data(numpy.ndarray):
         if self.in_memory:
             data = super(Data, self).reshape((len(urls), self.shape[-2], self.shape[-1])).view(numpy.ndarray)
         return Data(urls, self.metadata.flatten(), self.in_memory, data=data)
+
+
+class Transformation():
+
+    def __init__(self, kind, transformation, rotate):
+        self.transformation = transformation
+        self.rotate = rotate
+        self.kind = kind
+
+    @property
+    def label(self):
+        return 'degrees' if self.kind == 'rsm' else 'µm'
