@@ -26,7 +26,7 @@
 
 __authors__ = ["J. Garriga"]
 __license__ = "MIT"
-__date__ = "21/12/2020"
+__date__ = "29/09/2021"
 
 import numpy
 try:
@@ -38,6 +38,7 @@ import multiprocessing
 from multiprocessing import Pool
 from scipy.optimize import curve_fit
 from scipy.stats import skew, kurtosis
+from silx.math.medianfilter import medfilt2d
 
 
 def gaussian(x, a, b, c, d):
@@ -137,9 +138,58 @@ def compute_moments(values, data):
     stack = [values[i] * data[i] for i in range(len(data))]
     zsum = numpy.sum(data, axis=0)
     com = numpy.sum(stack, axis=0) / zsum
+    com = medfilt2d(com.astype(numpy.float64))
+    com[numpy.isnan(com)] = numpy.min(com[~numpy.isnan(com)])
     repeat_values = numpy.repeat(values, com.shape[0] * com.shape[1]).reshape(len(values), com.shape[0], com.shape[1])
     std = numpy.sqrt(numpy.sum((data[i] * ((repeat_values[i] - com)**2) for i in range(len(data))), axis=0)) / zsum
+    std = medfilt2d(std.astype(numpy.float64))
+    std[numpy.isnan(std)] = numpy.min(std[~numpy.isnan(std)])
     skews = skew(stack, axis=0)
     kurt = kurtosis(stack, axis=0)
 
     return com, std, skews, kurt
+
+
+def compute_rsm(H, W, d, ffz, mainx):
+    """
+    :param int H: height of the image in pixels.
+    :param int W: width of the image in pixels.
+    :param float d: Distance in micrometers of each pixel.
+    :param float ffz: motor 'ffz' value.
+    :param float mainx: motor 'mainx' value.
+
+    :returns: Tuple of two arrays of size (W, H)
+    :rtype: (X1, X2) : ndarray
+    """
+    pix_arr = numpy.meshgrid(numpy.arange(H), numpy.arange(W))
+    pix_arr[0] = (pix_arr[0] - W / 2) * d
+    pix_arr[1] = (H / 2 - pix_arr[1]) * d
+    pix_arr[0] = numpy.degrees(numpy.arctan2(pix_arr[0], numpy.sqrt(ffz * ffz + mainx * mainx)))
+    pix_arr[1] = numpy.degrees(numpy.arctan2(ffz - pix_arr[1], mainx))
+
+    return pix_arr
+
+
+def compute_magnification(H, W, d, obx, obpitch, mainx, topography=[False, 0]):
+    """
+    :param int H: height of the image in pixels.
+    :param int W: width of the image in pixels.
+    :param float d: Distance in micrometers of each pixel.
+    :param float obx: motor 'obx' value.
+    :param float obpitch: motor 'obpitch' value in the middle of the dataset.
+    :param float mainx: motor 'mainx' value.
+
+    :returns: Tuple of two arrays of size (H, W)
+    :rtype: (X1, X2) : ndarray
+    """
+
+    pix_arr = numpy.meshgrid(numpy.arange(H), numpy.arange(W))
+    d1 = obx / numpy.cos(numpy.radians(obpitch))
+    d2 = mainx / numpy.cos(numpy.radians(obpitch)) - d1
+    M = d2 / d1
+    d /= M
+    pix_arr[0] = (pix_arr[0] - W / 2) * d
+    pix_arr[1] = (H / 2 - pix_arr[1]) * d
+    if topography[0]:
+        pix_arr[topography[1]] /= numpy.sin(numpy.radians(obpitch))
+    return pix_arr
