@@ -364,7 +364,7 @@ class TestDataset(unittest.TestCase):
         dataset = utils.createRandomDataset(dims=(100, 100), nb_data_files=10, in_memory=False)
 
         num_components = 5
-        H, W = dataset.nmf(num_components=num_components, num_iter=10, cascade=[100, 50, 25])
+        H, W = dataset.nmf(num_components=num_components, num_iter=10, waterfall=[100, 50, 25])
 
         self.assertEqual(H.shape, (num_components, len(dataset.data[0].flatten())))
         self.assertEqual(W.shape, (dataset.nframes, num_components))
