@@ -26,7 +26,7 @@
 
 __authors__ = ["J. Garriga"]
 __license__ = "MIT"
-__date__ = "28/04/2020"
+__date__ = "22/12/2020"
 
 import numpy
 
@@ -39,13 +39,14 @@ from .displayComponentsWidget import DisplayComponentsWidget
 
 class Method(_Enum):
     """
-    Different shifts approaches that can be used for the shift detection and
-    correction.
+    Different blind source separation approaches that can be applied
     """
-    PCA = "PCA"
-    NNICA = "NNICA"
-    NMF = "NMF"
-    NNICA_NMF = "NNICA+NMF"
+    PCA = "The process of computing the principal components \n" \
+          "and using them to perform a change of basis on the data"
+    NICA = "Find components independent from each other and non-negative"
+    NMF = "Non-negative matrix factorization factorizes the data matrix into \n" \
+          "two matrices, with the property that all three matrices have no negative elements"
+    NICA_NMF = "Apply Non-negative ICA followed by NMF"
 
 
 class BSSWidget(qt.QMainWindow):
@@ -53,54 +54,51 @@ class BSSWidget(qt.QMainWindow):
     Widget to apply blind source separation.
     """
 
+    sigComputed = qt.Signal(Method, int)
+
     def __init__(self, parent=None):
         qt.QMainWindow.__init__(self, parent)
 
-        # Widget with the type of bss and the number of components to compute
-        top_widget = qt.QWidget(self)
-
+        # Method widget
         methodLabel = qt.QLabel("Method: ")
         self.methodCB = qt.QComboBox()
-        for method in Method.values():
-            self.methodCB.addItem(method)
+        for member in Method.members():
+            self.methodCB.addItem(member.name)
+            self.methodCB.setItemData(self.methodCB.count() - 1, member.value, qt.Qt.ToolTipRole)
+        # Number of components
         nComponentsLabel = qt.QLabel("Num comp:")
         self.nComponentsLE = qt.QLineEdit("1")
         self.nComponentsLE.setValidator(qt.QIntValidator())
+        # Compute BSS with the number of components
         self.computeButton = qt.QPushButton("Compute")
-        maxNComponentsLabel = qt.QLabel("Max number of components:")
-        self.maxNumComp = qt.QLineEdit("")
-        self.maxNumComp.setToolTip("For a specific number of components enter an "
-                                   "integer, for a\npercentage enter a float between "
-                                   "0 (included) and 1 (not included).\n"
-                                   "Float 0.5 will take as max number the 50% of "
-                                   "the images.\nEmpty text computes all components.")
-        self.maxNumComp.setValidator(qt.QDoubleValidator())
-        self.detectButton = qt.QPushButton("Detect number of components")
         self.computeButton.setEnabled(False)
+        self.computeButton.clicked.connect(self._computeBSS)
+        # Detect optimal number of components
+        self.detectButton = qt.QPushButton("Detect number of components")
         self.detectButton.setEnabled(False)
-        layout = qt.QGridLayout()
+        self.detectButton.clicked.connect(self._detectComp)
 
+        # Add widgets to layout
+        layout = qt.QGridLayout()
         layout.addWidget(methodLabel, 0, 0, 1, 1)
         layout.addWidget(self.methodCB, 0, 1, 1, 1)
         layout.addWidget(nComponentsLabel, 0, 2, 1, 1)
         layout.addWidget(self.nComponentsLE, 0, 3, 1, 1)
         layout.addWidget(self.computeButton, 0, 4, 1, 1)
-        layout.addWidget(maxNComponentsLabel, 1, 2, 1, 1)
-        layout.addWidget(self.maxNumComp, 1, 3, 1, 1)
         layout.addWidget(self.detectButton, 1, 4, 1, 1)
-
+        # Top Widget with the type of bss and the number of components to compute
+        top_widget = qt.QWidget(self)
         top_widget.setLayout(layout)
 
-        self.splitter = qt.QSplitter(qt.Qt.Vertical)
-        self.splitter.addWidget(top_widget)
-        self.setCentralWidget(self.splitter)
-
+        # Widget to display the components
         self._displayComponentsWidget = DisplayComponentsWidget()
-        self.splitter.addWidget(self._displayComponentsWidget)
         self._displayComponentsWidget.hide()
 
-        self.computeButton.clicked.connect(self._computeBSS)
-        self.detectButton.clicked.connect(self._detectComp)
+        # Main widget is a Splitter with the top widget and the displayComponentsWidget
+        self.splitter = qt.QSplitter(qt.Qt.Vertical)
+        self.splitter.addWidget(top_widget)
+        self.splitter.addWidget(self._displayComponentsWidget)
+        self.setCentralWidget(self.splitter)
 
     def hideButton(self):
         self._computeB.hide()
@@ -126,20 +124,23 @@ class BSSWidget(qt.QMainWindow):
         Computes blind source separation with the chosen method.
         """
         self.computeButton.setEnabled(False)
+        self.detectButton.setEnabled(False)
         self.nComponentsLE.setEnabled(False)
-        method = Method(self.methodCB.currentText())
+        method = Method[self.methodCB.currentText()]
         n_comp = int(self.nComponentsLE.text())
+        self.sigComputed.emit(method, n_comp)
         if method == Method.PCA:
-            self._thread = OperationThread(self.dataset.pca)
-        elif method == Method.NNICA:
-            self._thread = OperationThread(self.dataset.nica)
+            self._thread = OperationThread(self, self.dataset.pca)
+        elif method == Method.NICA:
+            self._thread = OperationThread(self, self.dataset.nica)
         elif method == Method.NMF:
-            self._thread = OperationThread(self.dataset.nmf)
-        elif method == Method.NNICA_NMF:
-            self._thread = OperationThread(self.dataset.nica_nmf)
+            self._thread = OperationThread(self, self.dataset.nmf)
+        elif method == Method.NICA_NMF:
+            self._thread = OperationThread(self, self.dataset.nica_nmf)
         else:
             raise ValueError('BSS method not managed')
 
+        # Set arguments and start thread
         self._thread.setArgs(n_comp, indices=self.indices)
         self._thread.finished.connect(self._displayComponents)
         self._thread.start()
@@ -160,6 +161,7 @@ class BSSWidget(qt.QMainWindow):
         self._displayComponentsWidget.show()
         self.computeButton.setEnabled(True)
         self.nComponentsLE.setEnabled(True)
+        self.detectButton.setEnabled(True)
         if self.bg_indices is not None:
             # If filter data is activated, the matrix W has reduced dimensionality, so reshaping is not possible
             # Create empty array with shape the total number of frames
@@ -167,11 +169,12 @@ class BSSWidget(qt.QMainWindow):
             # Set actual values of W where threshold of filter is True
             W[self.indices] = self.W
             self.W = W
-        self._displayComponentsWidget.setComponents(self.comp, self.W, self.dataset.get_dimensions_values())
+        self._displayComponentsWidget.setComponents(self.comp, self.W, self.dataset.get_dimensions_values(), self.dataset.data.shape[:2])
 
     def _detectComp(self):
         self.detectButton.setEnabled(False)
-        self._thread = OperationThread(self.dataset.pca)
+        self.computeButton.setEnabled(False)
+        self._thread = OperationThread(self, self.dataset.pca)
         self._thread.setArgs(return_vals=True)
         self._thread.finished.connect(self._setNumComp)
         self._thread.start()
@@ -182,4 +185,8 @@ class BSSWidget(qt.QMainWindow):
         vals /= numpy.sum(vals)
         components = len(vals[vals > 0.01])
         self.detectButton.setEnabled(True)
+        self.computeButton.setEnabled(True)
         self.nComponentsLE.setText(str(components))
+
+    def getDisplayComponentsWidget(self):
+        return self._displayComponentsWidget
