@@ -25,14 +25,14 @@
 
 __authors__ = ["H. Payno", "J. Garriga"]
 __license__ = "MIT"
-__date__ = "16/12/2019"
+__date__ = "26/04/2021"
 
 import numpy
 from functools import partial
 
 from silx.gui import qt
-from darfix.core.dataset import Dataset, Dimension
-from darfix.core.dataset import _METADATA_TYPES, _METADATA_TYPES_I, DEFAULT_METADATA
+from darfix.core.dataset import Dataset
+from darfix.core.dimension import Dimension, _METADATA_TYPES, _METADATA_TYPES_I, DEFAULT_METADATA
 import logging
 
 _logger = logging.getLogger(__file__)
@@ -218,10 +218,16 @@ class DimensionWidget(DimensionMapping):
     def _updateTolerance(self, tolerance=None):
         if tolerance is None:
             tolerance = self._toleranceLE.text()
-        self.tolerance = float(tolerance)
+        try:
+            self.tolerance = float(tolerance)
+        except ValueError:
+            _logger.warning("Wrong tolerance")
 
     def clear(self):
         super().clear()
+        if self.dataset is None:
+            _logger.warning('No dataset to be fitted')
+            return
         self.dataset.clear_dims()
 
     def setDataset(self, dataset, indices=None, bg_indices=None, bg_dataset=None):
@@ -261,11 +267,11 @@ class DimensionWidget(DimensionMapping):
         :returns: return status of the fit and fail reason, if any
         :rtype: Union[bool,str,None]
         """
-        qt.QApplication.setOverrideCursor(qt.Qt.WaitCursor)
         if self.dataset is None:
             _logger.warning('No dataset to be fitted')
             return
 
+        qt.QApplication.setOverrideCursor(qt.Qt.WaitCursor)
         msg = qt.QMessageBox()
         try:
             if self.dims:
@@ -284,6 +290,7 @@ class DimensionWidget(DimensionMapping):
                 self.addDim(dim[0], dim[1])
             self._update_dataset = self.dataset.reshape_data()
         except Exception as e:
+            self.dataset.clear_dims()
             msg.setIcon(qt.QMessageBox.Warning)
             msg.setText("Error: {0}".format(e))
             msg.setWindowTitle("Fit failed!")
@@ -386,6 +393,7 @@ class _DimensionItem(Dimension, qt.QWidget):
             else:
                 assert type(size) is int
                 self._sizeSP.show()
+                self._sizeSP.setMaximum(max(99, 2 * size))
                 self._sizeSP.setValue(size)
                 self.setEnabled(editable)
 
@@ -471,10 +479,12 @@ class _DimensionItem(Dimension, qt.QWidget):
         self.removed.emit(self)
 
     def showUniqueNames(self):
-        title = "%s - %s unique names" % (_METADATA_TYPES_I[self.kind], self.name)
+        title = "%s - %s" % (_METADATA_TYPES_I[self.kind], self.name)
+        ptp = float(self.unique_values[-1]) - float(self.unique_values[0])
         unique_values_str = []
         [unique_values_str.append(str(val)) for val in self.unique_values]
-        qt.QMessageBox.information(self, title, ', '.join(unique_values_str))
+        msg = 'Unique values: [' + ', '.join(unique_values_str) + ']\n Ptp: ' + str(ptp)
+        qt.QMessageBox.information(self, title, msg)
 
     def setUniqueValues(self, values):
         super().set_unique_values(values)
@@ -497,6 +507,7 @@ class _DimensionItem(Dimension, qt.QWidget):
         if dim.size is not None:
             self._sizeWidget.setValue(dim.size)
         self._setTolerance(str(dim.tolerance))
+        self.setUniqueValues(dim.unique_values)
 
     @property
     def _row(self):
