@@ -30,6 +30,7 @@ __date__ = "10/08/2021"
 
 from matplotlib.colors import hsv_to_rgb
 import numpy
+import logging
 
 from silx.gui import qt
 from silx.gui.colors import Colormap
@@ -42,6 +43,8 @@ from silx.io.dictdump import dicttonx
 import darfix
 from .operationThread import OperationThread
 
+_logger = logging.getLogger(__file__)
+
 
 class Method(_Enum):
     """
@@ -120,13 +123,14 @@ class GrainPlotWidget(qt.QMainWindow):
             self._methodCB.model().item(i).setEnabled(False)
         scale = 100
         if self.dataset.transformation:
-            px = self.dataset.transformation[0][0][0]
-            py = self.dataset.transformation[1][0][0]
-            xscale = (self.dataset.transformation[0][-1][-1] - px) / len(self.dataset.transformation[0][0])
-            yscale = (self.dataset.transformation[1][-1][-1] - py) / len(self.dataset.transformation[1][0])
+            transformation = self.dataset.transformation.transformation
+            px = transformation[0][0][0]
+            py = transformation[1][0][0]
+            xscale = (transformation[0][-1][-1] - px) / len(transformation[0][0])
+            yscale = (transformation[1][-1][-1] - py) / len(transformation[1][0])
             self.origin = (px, py)
             self.scale = (xscale, yscale)
-        if self.dataset.dims.ndim > 1:
+        if self.dataset.dims.ndim == 2:
             self._curves = {}
             self.ori_dist, self.hsv_key = self.dataset.compute_mosaicity_colorkey()
             xdim = self.dataset.dims.get(1)
@@ -247,34 +251,64 @@ class GrainPlotWidget(qt.QMainWindow):
             self._plotWidget.hide()
         elif method == Method.FWHM:
             self._plotWidget.show()
-            for i, plot in enumerate(self._plots):
-                plot.addImage(darfix.config.FWHM_VAL * self._moments[i][1])
+            if self.dataset.transformation is not None:
+                label = self.dataset.transformation.label
+                for i, plot in enumerate(self._plots):
+                    plot.addImage(darfix.config.FWHM_VAL * (numpy.rot90(self._moments[i][1], 3)
+                                  if self.dataset.transformation.rotate else self._moments[i][0]),
+                                  origin=self.origin, scale=self.scale,
+                                  xlabel=label, ylabel=label)
+            else:
+                for i, plot in enumerate(self._plots):
+                    plot.addImage(darfix.config.FWHM_VAL * self._moments[i][1])
         elif method == Method.COM:
             self._plotWidget.show()
             if self.dataset.transformation is not None:
+                label = self.dataset.transformation.label
                 for i, plot in enumerate(self._plots):
-                    plot.addImage(self._moments[i][0], origin=self.origin, scale=self.scale, xlabel='µm', ylabel='µm')
+                    plot.addImage(numpy.rot90(self._moments[i][0], 3) if self.dataset.transformation.rotate
+                                  else self._moments[i][0], origin=self.origin, scale=self.scale,
+                                  xlabel=label, ylabel=label)
             else:
                 for i, plot in enumerate(self._plots):
                     plot.addImage(self._moments[i][0], xlabel='pixels', ylabel='pixels')
         elif method == Method.SKEWNESS:
             self._plotWidget.show()
-            for i, plot in enumerate(self._plots):
-                plot.addImage(self._moments[i][2])
+            if self.dataset.transformation is not None:
+                label = self.dataset.transformation.label
+                for i, plot in enumerate(self._plots):
+                    plot.addImage(numpy.rot90(self._moments[i][2], 3) if self.dataset.transformation.rotate
+                                  else self._moments[i][2], origin=self.origin, scale=self.scale,
+                                  xlabel=label, ylabel=label)
+            else:
+                for i, plot in enumerate(self._plots):
+                    plot.addImage(self._moments[i][2], xlabel='pixels', ylabel='pixels')
         elif method == Method.KURTOSIS:
             self._plotWidget.show()
-            for i, plot in enumerate(self._plots):
-                plot.addImage(self._moments[i][3])
-        elif method == Method.MOSAICITY:
-            self._plotWidget.hide()
-            if self.dataset.transformation:
-                self._mosaicityPlot.addImage(hsv_to_rgb(self._computeMosaicity()),
-                                             origin=self.origin, scale=self.scale,
-                                             xlabel='µm', ylabel='µm')
+            if self.dataset.transformation is not None:
+                label = self.dataset.transformation.label
+                for i, plot in enumerate(self._plots):
+                    plot.addImage(numpy.rot90(self._moments[i][3], 3) if self.dataset.transformation.rotate
+                                  else self._moments[i][3], origin=self.origin, scale=self.scale,
+                                  xlabel=label, ylabel=label)
             else:
-                self._mosaicityPlot.addImage(hsv_to_rgb(self._computeMosaicity()))
+                for i, plot in enumerate(self._plots):
+                    plot.addImage(self._moments[i][0], xlabel='pixels', ylabel='pixels')
+        elif method == Method.MOSAICITY:
+            try:
+                self._plotWidget.hide()
+                if self.dataset.transformation:
+                    label = self.dataset.transformation.label
+                    image = hsv_to_rgb(self._computeMosaicity())
+                    self._mosaicityPlot.addImage(numpy.rot90(image, 3) if self.dataset.transformation.rotate
+                                                 else image, origin=self.origin, scale=self.scale,
+                                                 xlabel=label, ylabel=label)
+                else:
+                    self._mosaicityPlot.addImage(hsv_to_rgb(self._computeMosaicity()))
 
-            self._mosaicityPlot.show()
+                self._mosaicityPlot.show()
+            except Exception:
+                _logger.error("Couldn't compute mosaicity")
 
     def _opticolor(self, img, minc, maxc):
         img = img.copy()
