@@ -26,7 +26,7 @@
 
 __authors__ = ["J. Garriga"]
 __license__ = "MIT"
-__date__ = "16/07/2021"
+__date__ = "23/09/2021"
 
 
 from silx.gui import qt
@@ -57,6 +57,11 @@ class MagnificationWidget(qt.QMainWindow):
         self._checkbox2x = qt.QCheckBox("2x magnification")
         self._checkbox10x = qt.QCheckBox("10x magnification")
         self._checkboxManual = qt.QCheckBox("Manual magnification:")
+        self._topographyCheckbox = qt.QCheckBox("Topography (obpitch)")
+        self._topographyCheckbox.hide()
+        self._orientationCB = qt.QComboBox()
+        self._orientationCB.addItems(["Horizontal", "Vertical"])
+        topographyAxis = qt.QLabel("Topography axis: ")
         self._manualLE = qt.QLineEdit(parent=self)
         self._manualLE.setEnabled(False)
         validator = qt.QDoubleValidator()
@@ -69,12 +74,22 @@ class MagnificationWidget(qt.QMainWindow):
         layout.addWidget(self._checkbox10x)
         layout.addWidget(self._checkboxManual)
         layout.addWidget(self._manualLE)
+        layout.addWidget(self._topographyCheckbox, alignment=qt.Qt.AlignRight)
+        self._topographyWidget = qt.QWidget()
+        topographyLayout = qt.QHBoxLayout()
+        topographyLayout.addWidget(topographyAxis)
+        topographyLayout.addWidget(self._orientationCB)
+        self._topographyWidget.setLayout(topographyLayout)
+        self._topographyWidget.hide()
+        self._topographyWidget.setMaximumHeight(40)
+        layout.addWidget(self._topographyWidget, alignment=qt.Qt.AlignRight)
         layout.addWidget(self._okButton)
 
         # self._okButton.pressed.connect(self._saveMagnification)
         self._checkbox2x.stateChanged.connect(self._check2x)
         self._checkbox10x.stateChanged.connect(self._check10x)
         self._checkboxManual.stateChanged.connect(self._checkManual)
+        self._topographyCheckbox.stateChanged.connect(self._checkTopography)
 
         self._checkbox2x.setChecked(True)
         widget.setLayout(layout)
@@ -100,6 +115,9 @@ class MagnificationWidget(qt.QMainWindow):
             msg.exec_()
         else:
             self._okButton.setEnabled(True)
+            for axis, dim in self.dataset.dims:
+                if dim.name == "obpitch":
+                    self._topographyCheckbox.show()
 
     @property
     def magnification(self):
@@ -142,6 +160,12 @@ class MagnificationWidget(qt.QMainWindow):
             self._checkboxManual.setChecked(False)
             self._manualLE.setEnabled(False)
 
+    def _checkTopography(self, checked):
+        if checked:
+            self._topographyWidget.show()
+        else:
+            self._topographyWidget.hide()
+
     def _saveMagnification(self):
 
         if self._checkbox2x.isChecked():
@@ -158,6 +182,7 @@ class MagnificationWidget(qt.QMainWindow):
                 return
         self._magnification = float(magnification)
 
-        self.dataset.compute_transformation(self.magnification)
+        self.dataset.compute_transformation(self.magnification, topography=[self._topographyCheckbox.isChecked(),
+                                            self._orientationCB.currentIndex()])
 
         self.sigComputed.emit()
