@@ -26,7 +26,7 @@
 
 __authors__ = ["J. Garriga"]
 __license__ = "MIT"
-__date__ = "11/12/2020"
+__date__ = "26/04/2021"
 
 # import os
 
@@ -61,6 +61,7 @@ class ROISelectionWidget(qt.QWidget):
         self.indices = None
         self.bg_indices = None
         self.bg_dataset = None
+        self._original_dataset = True
 
         self.setLayout(qt.QVBoxLayout())
         self._sv = StackViewMainWindow()
@@ -173,14 +174,17 @@ class ROISelectionWidget(qt.QWidget):
         and show the new data in the stack. Dataset data is not yet replaced.
         A new roi is created in the middle of the new stack.
         """
-        self._abortB.show()
+        if not self._update_dataset.in_memory:
+            self._abortB.show()
         self._applyB.setEnabled(False)
         self._okB.setEnabled(False)
         self.roi = RectangleROI()
         self.roi.setGeometry(origin=self.getRoi().getOrigin(), size=self.getRoi().getSize())
         self.thread = OperationThread(self, self._update_dataset.apply_roi)
+        roi_dir = self._update_dataset.dir if not self._original_dataset else None
         self.thread.setArgs(size=numpy.flip(self.roi.getSize()),
-                            center=numpy.flip(self.roi.getCenter()))
+                            center=numpy.flip(self.roi.getCenter()),
+                            roi_dir=roi_dir)
         self.thread.finished.connect(self._updateData)
         self.thread.start()
 
@@ -199,6 +203,7 @@ class ROISelectionWidget(qt.QWidget):
         self._okB.setEnabled(True)
         if self.thread.data:
             self._update_dataset = self.thread.data
+            self._original_dataset = False
             assert self._update_dataset is not None
             self.setStack(self._update_dataset)
             self.resetROI()
@@ -212,15 +217,15 @@ class ROISelectionWidget(qt.QWidget):
         Signal emitted with the roi parameters.
         """
         if self.roi:
-            if self.bg_dataset is not None:
-                self.bg_dataset = self.bg_dataset.apply_roi(size=numpy.flip(self.roi.getSize()),
-                                                            center=numpy.flip(self.roi.getCenter()))
             self.sigComputed.emit(self.roi.getOrigin().tolist(), self.roi.getSize().tolist())
         else:
             self.sigComputed.emit([], [])
 
     def getDataset(self):
-        return self._update_dataset, self.indices, self.bg_indices, self.bg_dataset
+        bg_dataset = (self.bg_dataset.apply_roi(size=numpy.flip(self.roi.getSize()),
+                                                center=numpy.flip(self.roi.getCenter()))
+                      if self.bg_dataset is not None else None)
+        return self._update_dataset, self.indices, self.bg_indices, bg_dataset
 
     def getStackViewColormap(self):
         """
@@ -254,6 +259,7 @@ class ROISelectionWidget(qt.QWidget):
         """
         self.roi = None
         self._update_dataset = self.dataset
+        self._original_dataset = True
         self.setStack(self.dataset)
 
     def clearStack(self):
