@@ -289,7 +289,7 @@ class ShiftCorrectionWidget(qt.QMainWindow):
 
     @shift.setter
     def shift(self, shift):
-        self._shift = shift
+        self._shift = numpy.array(shift)
         self._inputDock.widget.setDx(shift[1])
         self._inputDock.widget.setDy(shift[0])
 
