@@ -58,6 +58,8 @@ class NoiseRemovalWidgetOW(OWWidget):
     background_type = Setting(str())
     kernel_size = Setting(str())
     bottom_threshold = Setting(str())
+    chunks = Setting(list())
+    step = Setting(str())
 
     def __init__(self):
         super().__init__()
@@ -79,6 +81,10 @@ class NoiseRemovalWidgetOW(OWWidget):
                 self._widget.mainWindow.size = self.kernel_size
             if self.bottom_threshold:
                 self._widget.mainWindow.bottom_threshold = self.bottom_threshold
+            if self.step:
+                self._widget.mainWindow.step = self.step
+            if self.chunks:
+                self._widget.mainWindow.chunks = self.chunks
         else:
             self._widget.mainWindow.clearStack()
             # Emit None
@@ -96,6 +102,8 @@ class NoiseRemovalWidgetOW(OWWidget):
         self.method = self._widget.mainWindow.method
         self.background_type = self._widget.mainWindow.background
         self.kernel_size = self._widget.mainWindow.size
+        self.step = self._widget.mainWindow.step
+        self.chunks = self._widget.mainWindow.chunks
         self.bottom_threshold = self._widget.mainWindow.bottom_threshold
         self.Outputs.dataset.send(self._widget.mainWindow.getDataset())
         self.Outputs.colormap.send(self._widget.mainWindow.getStackViewColormap())
